Index: INSTALL.txt
===================================================================
RCS file: /cvs/drupal/drupal/INSTALL.txt,v
retrieving revision 1.75
diff -u -p -r1.75 INSTALL.txt
--- INSTALL.txt	22 Aug 2009 16:01:10 -0000	1.75
+++ INSTALL.txt	9 Sep 2009 11:27:18 -0000
@@ -119,8 +119,8 @@ INSTALLATION
    (e.g., http://www.example.com).
 
    You will be guided through several screens to set up the database,
-   create tables, add the first user account and provide basic web
-   site settings.
+   create tables, add the site maintenance account (the first user, also known 
+   as User/1), and provide basic web site settings.
 
    The install script will attempt to create a files storage directory
    in the default location at sites/default/files (the location of the
@@ -152,8 +152,8 @@ INSTALLATION
 5. CONFIGURE DRUPAL
 
    When the install script succeeds, you will be directed to the "Welcome"
-   page, and you will be logged in as the administrator already. Proceed with
-   the initial configuration steps suggested on the "Welcome" page.
+   page, and you will be logged in as the site maintenance account already. Proceed
+   with the initial configuration steps suggested on the "Welcome" page.
 
    If the default Drupal theme is not displaying properly and links on the page
    result in "Page Not Found" errors, try manually setting the $base_url variable
Index: UPGRADE.txt
===================================================================
RCS file: /cvs/drupal/drupal/UPGRADE.txt,v
retrieving revision 1.15
diff -u -p -r1.15 UPGRADE.txt
--- UPGRADE.txt	11 Aug 2009 17:26:33 -0000	1.15
+++ UPGRADE.txt	9 Sep 2009 11:27:18 -0000
@@ -36,10 +36,10 @@ Let's begin!
     More information on multisite configuration is located in INSTALL.txt.
 
 2.  If possible, log on as the user with user ID 1, which is the first account
-    created and the main administrator account. User ID 1 will be able to
-    automatically access update.php in step #10. There are special instructions
-    in step #10 if you are unable to log on as user ID 1. Do not close your
-    browser until the final step is complete.
+    created - also known as the site maintenance account. Only this account will
+    be able to automatically access update.php in step #10. There are special 
+    instructions in step #10 if you are unable to log on as user ID 1. Do not 
+    close your browser until the final step is complete.
 
 3.  Place the site in "Offline" mode, to let the database updates run without
     interruption and avoid displaying errors to end users of the site. This
Index: install.php
===================================================================
RCS file: /cvs/drupal/drupal/install.php,v
retrieving revision 1.202
diff -u -p -r1.202 install.php
--- install.php	25 Aug 2009 21:53:46 -0000	1.202
+++ install.php	9 Sep 2009 11:27:18 -0000
@@ -45,7 +45,7 @@ define('INSTALL_TASK_RUN_IF_REACHED', 2)
  * once and be marked complete once they are successfully finished. For
  * example, the Drupal installer uses this flag for the batch installation of
  * modules on the new site, and also for the configuration form that collects
  * basic site information and sets up the first user account.
  */
 define('INSTALL_TASK_RUN_IF_NOT_COMPLETED', 3);
 
@@ -1001,8 +1001,7 @@ function install_find_profiles() {
 }
 
 /**
- * Installation task; allow the site administrator to select which profile to
- * install.
+ * Installation task; select which profile to install
  *
  * @param $install_state
  *   An array of information about the current installation state. The chosen
@@ -1118,8 +1117,7 @@ function install_find_locales($profilena
 }
 
 /**
- * Installation task; allow the site administrator to select which locale to
- * use for the current profile.
+ * Installation task; select which locale to use for the current profile
  *
  * @param $install_state
  *   An array of information about the current installation state. The chosen
@@ -1556,7 +1554,7 @@ function _install_configure_form(&$form_
   );
   $form['admin_account'] = array(
     '#type' => 'fieldset',
-    '#title' => st('Administrator account'),
+    '#title' => st('Site maintenance account'),
     '#collapsible' => FALSE,
   );
 
@@ -1678,7 +1676,7 @@ function install_configure_form_submit($
   if ($form_state['values']['update_status_module'][1]) {
     drupal_install_modules(array('update'));
  
     // Add the administrator's email address to the list of addresses to be
     // notified when updates are available, if selected.
     if ($form_state['values']['update_status_module'][2]) {
       variable_set('update_notify_emails', array($form_state['values']['account']['mail']));
@@ -45,7 +45,7 @@ define('INSTALL_TASK_RUN_IF_REACHED', 2)
  * example, the Drupal installer uses this flag for the batch installation of
  * modules on the new site, and also for the configuration form that collects
- * basic site information and sets up the first user account.
+ * basic site information and sets up the site maintenance account.
  */
 define('INSTALL_TASK_RUN_IF_NOT_COMPLETED', 3);
@@ -1678,7 +1676,7 @@ function install_configure_form_submit($
     drupal_install_modules(array('update'));
  
-    // Add the administrator's email address to the list of addresses to be
+    // Add the site maintenance account's email address to the list of addresses to be
     // notified when updates are available, if selected.
     if ($form_state['values']['update_status_module'][2]) {
Index: update.php
===================================================================
RCS file: /cvs/drupal/drupal/update.php,v
retrieving revision 1.302
diff -u -p -r1.302 update.php
--- update.php	7 Sep 2009 15:43:54 -0000	1.302
+++ update.php	9 Sep 2009 11:27:18 -0000
@@ -13,9 +13,10 @@ define('DRUPAL_ROOT', getcwd());
  * Point your browser to "http://www.example.com/update.php" and follow the
  * instructions.
  *
  * If you are not logged in as administrator, you will need to modify the access
  * check statement inside your settings.php file. After finishing the upgrade,
  * be sure to open settings.php again, and change it back to its original state!
  */
 
 /**
@@ -201,12 +202,12 @@ function update_info_page() {
 
 function update_access_denied_page() {
   drupal_set_title('Access denied');
-  return '<p>Access denied. You are not authorized to access this page. Please log in as the admin user (the first user you created). If you cannot log in, you will have to edit <code>settings.php</code> to bypass this access check. To do this:</p>
+  return '<p>Access denied. You are not authorized to access this page. Please log in using the site maintenance account (the first user account you created). If you cannot log in, you will have to edit <code>settings.php</code> to bypass this access check. To do this:</p>
 <ol>
  <li>With a text editor find the settings.php file on your system. From the main Drupal directory that you installed all the files into, go to <code>sites/your_site_name</code> if such directory exists, or else to <code>sites/default</code> which applies otherwise.</li>
  <li>There is a line inside your settings.php file that says <code>$update_free_access = FALSE;</code>. Change it to <code>$update_free_access = TRUE;</code>.</li>
  <li>As soon as the update.php script is done, you must change the settings.php file back to its original form with <code>$update_free_access = FALSE;</code>.</li>
- <li>To avoid having this problem in future, remember to log in to your website as the admin user (the user you first created) before you backup your database at the beginning of the update process.</li>
+ <li>To avoid having this problem in future, remember to log in to your website using the site maintenance account (the first user account you created) before you backup your database at the beginning of the update process.</li>
 </ol>';
 }
 
@@ -13,9 +13,10 @@ define('DRUPAL_ROOT', getcwd());
  * instructions.
  *
- * If you are not logged in as administrator, you will need to modify the access
- * check statement inside your settings.php file. After finishing the upgrade,
- * be sure to open settings.php again, and change it back to its original state!
+ * If you are not logged in using the site maintenance account, you will need
+ * to modify the access check statement inside your settings.php file. After 
+ * finishing the upgrade, be sure to open settings.php again, and change it back
+ * to its original state!
  */
 
